# Python Extends LaTeX

## Overview

This project is aimed at creating LaTeX documents using only Python,
without directly writing LaTeX code. Rather
than building a direct Python API to LaTeX, this package has its own,
simpler API to creating documents.

## Links

See the
[documentation here.](
https://nickderobertis.github.io/py-ex-latex/
)

## Author

Created by Nick DeRobertis. MIT License.